fn builtin_match_fun(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Look up a function by name or return it if already a function.
@param FUN function or character string naming a function @return the function @namespace base