builtin_simple_condition

Function builtin_simple_condition 

fn builtin_simple_condition(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Construct a simple condition object.

@param msg character string giving the condition message @param call the call associated with the condition (default NULL) @param class additional class to prepend to “condition” @return a condition list with message, call, and class attributes