builtin_simple_error

Function builtin_simple_error 

fn builtin_simple_error(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Construct a simple error condition object.

@param message character string giving the error message @param call the call associated with the error (default NULL) @return a condition list with class c(“simpleError”, “error”, “condition”)