fn builtin_simple_warning(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Construct a simple warning condition object.
@param message character string giving the warning message @param call the call associated with the warning (default NULL) @return a condition list with class c(“simpleWarning”, “warning”, “condition”)