builtin_stop

Function builtin_stop 

fn builtin_stop(
    args: &[RValue],
    _named: &[(String, RValue)],
) -> Result<RValue, RError>
Signal an error condition and stop execution.

@param … character strings concatenated into the error message, or a condition object @param call. logical, whether to include the call in the condition (default TRUE, currently ignored) @return does not return; signals an error