interp_signal_condition

Function interp_signal_condition 

fn interp_signal_condition(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Signal a condition object to calling handlers without unwinding.

This is the low-level primitive used by the condition system. It walks the handler stack and invokes matching handlers in calling-handler style (the handler runs and then returns to the signaler).

@param c a condition object (list with class attribute containing condition classes) @return NULL, invisibly