interp_open

Function interp_open 

fn interp_open(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Open a connection.

If the connection is already open this is a no-op. Otherwise the mode is recorded and the connection is marked open.

@param con integer scalar: connection ID @param open character scalar: open mode (default “r”) @return the connection (invisibly)