pre_eval_with

Function pre_eval_with 

fn pre_eval_with(
    args: &[Arg],
    env: &Environment,
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Evaluate an expression in the context of a data frame.

Creates an environment where the data frame’s columns are accessible as variables, then evaluates expr in that environment.

@param data a data frame (or list) @param expr expression to evaluate @return the result of evaluating expr