fn builtin_base64enc(
args: &[RValue],
_named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Encode a character string or raw vector to base64.
@param x character string or raw vector to encode @return character string with base64 encoding