builtin_blake3_file

Function builtin_blake3_file 

fn builtin_blake3_file(
    args: &[RValue],
    _named: &[(String, RValue)],
) -> Result<RValue, RError>
Compute a BLAKE3 hash of a file’s contents using streaming I/O.

Reads the file in chunks to avoid loading the entire file into memory, making it efficient for large files.

@param path character scalar: path to the file to hash @return character scalar containing the 64-char hex digest