builtin_md5

Function builtin_md5 

fn builtin_md5(
    _args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
MD5 is deprecated — error stub suggesting SHA-256.

MD5 is cryptographically broken and should not be used for any purpose. This function always errors with a suggestion to use digest(x, algo="sha256").

@param x ignored @return always errors