fn builtin_col_names(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Get the column names of a data frame or matrix.
@param x data frame, matrix, or object with dimnames @return character vector of column names, or NULL