builtin_col_names_set

Function builtin_col_names_set 

fn builtin_col_names_set(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Set the column names of a data frame or matrix.

@param x data frame, matrix, or object with dimnames @param value character vector of new column names, or NULL @return the modified object