builtin_dim_set

Function builtin_dim_set 

fn builtin_dim_set(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Set the dimensions of an object, converting it to a matrix or array.

@param x vector to reshape @param value integer vector of new dimensions, or NULL to remove @return the reshaped object