builtin_find_interval

Function builtin_find_interval 

fn builtin_find_interval(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Find the interval index containing each element of x.

For a sorted vector vec of length N, returns an integer vector of the same length as x, where each value is in 0..N indicating which interval the corresponding x value falls into (0 = before vec[0], N = after vec[N-1]).

@param x numeric vector @param vec sorted numeric vector of break points @return integer vector of interval indices