builtin_ifelse

Function builtin_ifelse 

fn builtin_ifelse(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Vectorized conditional: for each element of test, select the corresponding element from yes (when TRUE) or no (when FALSE). yes and no are recycled to the length of test.

@param test logical vector @param yes values to use where test is TRUE (recycled) @param no values to use where test is FALSE (recycled) @return vector of same length as test, with elements drawn from yes or no