builtin_inherits

Function builtin_inherits 

fn builtin_inherits(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Test if an object inherits from one or more classes.

Checks the object’s class vector for any matches with the given class names.

@param x object to test @param what character vector of class names to check @return logical scalar