builtin_rbind

Function builtin_rbind 

fn builtin_rbind(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Bind vectors, matrices, or data frames by rows.

Combines arguments row-wise. If any argument is a data frame, produces a data frame result by matching columns by name. Otherwise produces a matrix.

@param … vectors, matrices, or data frames to bind @return matrix or data frame