builtin_row_names

Function builtin_row_names 

fn builtin_row_names(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Get the row names of a data frame or matrix.

@param x data frame, matrix, or object with dimnames @return character vector of row names, or NULL