fn builtin_row_names_set(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Set the row names of a data frame or matrix.
@param x data frame, matrix, or object with dimnames @param value character vector of new row names, or NULL @return the modified object