builtin_use_method

Function builtin_use_method 

fn builtin_use_method(
    _args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
UseMethod() is intercepted directly by the evaluator so it can unwind the current generic frame instead of returning like an ordinary builtin.