fn builtin_vector(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Create a vector of a given mode and length.
@param mode type of vector (“numeric”, “integer”, “character”, “logical”, “list”) @param length number of elements (default: 0) @return vector initialized with default values for the mode