interp_traceback

Function interp_traceback 

fn interp_traceback(
    _args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Print the call stack of the last error.

Displays the call stack that was active when the last error occurred, numbered from the bottom (outermost) to the top (innermost) of the stack.

@param x number of calls to display (ignored) @return the traceback as a character vector, invisibly