synthesize_builtin_help

Function synthesize_builtin_help 

pub fn synthesize_builtin_help(index: &mut RdHelpIndex)
Synthesize RdDoc help pages from all builtin descriptors and register them in the help index. This gives every builtin a rich help page (title, usage, arguments, return value) derived from rustdoc comments.