fn ensure_plot<'a>(ctx: &'a BuiltinContext<'_>) -> RefMut<'a, Option<PlotState>>Expand description
Ensure a current plot exists, creating a new one if needed.
fn ensure_plot<'a>(ctx: &'a BuiltinContext<'_>) -> RefMut<'a, Option<PlotState>>Ensure a current plot exists, creating a new one if needed.