fn auto_grob_name(prefix: &str, ctx: &BuiltinContext<'_>) -> StringExpand description
Generate a unique grob name with the given prefix and a counter.
fn auto_grob_name(prefix: &str, ctx: &BuiltinContext<'_>) -> StringGenerate a unique grob name with the given prefix and a counter.