fn find_viewport_by_name(name: &str, ctx: &BuiltinContext<'_>) -> Option<usize>Expand description
Find a viewport by name in the viewport stack. Returns the index in the stack if found.
fn find_viewport_by_name(name: &str, ctx: &BuiltinContext<'_>) -> Option<usize>Find a viewport by name in the viewport stack. Returns the index in the stack if found.