fn interp_grid_layout(
args: &[RValue],
named: &[(String, RValue)],
_context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Create a grid layout object specifying rows and columns.
@param nrow number of rows (default 1) @param ncol number of columns (default 1) @param widths column widths (unit object) @param heights row heights (unit object) @param respect logical or matrix controlling aspect ratio respect @return a layout object (list with class “layout”)