interp_seek_viewport

Function interp_seek_viewport 

fn interp_seek_viewport(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Find and navigate to a named viewport anywhere in the viewport tree.

@param name the name of the viewport to seek @return the depth navigated (integer), or error if not found