interp_assign

Function interp_assign 

fn interp_assign(
    positional: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Assign a value to a variable name in an environment.

@param x character string giving the variable name @param value the value to assign @param envir environment in which to make the assignment (default: calling environment) @return the assigned value, invisibly