fn interp_binding_is_locked(
positional: &[RValue],
_named: &[(String, RValue)],
_context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Check whether a binding is locked in an environment.
@param sym name of the binding to check (character string) @param env environment containing the binding @return logical scalar: TRUE if the binding is locked, FALSE otherwise