interp_do_call

Function interp_do_call 

fn interp_do_call(
    positional: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Call a function with arguments supplied as a list.

Named elements in the list are passed as named arguments to the function. Unnamed elements are passed as positional arguments.

@param what function or character string naming the function @param args list of arguments to pass to the function @param quote if TRUE, do not evaluate the arguments (default FALSE) @return the result of the function call