interp_get

Function interp_get 

fn interp_get(
    positional: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Look up a variable by name in an environment.

@param x character string giving the variable name @param envir environment in which to look up the variable (default: calling environment) @return the value bound to the name