interp_get_namespace

Function interp_get_namespace 

fn interp_get_namespace(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Get a namespace environment by name.

Returns the namespace environment for a loaded package. If the namespace is not yet loaded, attempts to load it (like GNU R’s getNamespace). Falls back to the base environment for builtin namespaces like “base”.

@param ns character scalar: namespace name @return environment @namespace base