interp_get_option

Function interp_get_option 

fn interp_get_option(
    positional: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Get the value of a named global option.

@param name character string — the option name @param default value to return if the option is not set (default NULL) @return the option value, or default if not set