interp_match_call

Function interp_match_call 

fn interp_match_call(
    _positional: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Return the call expression with arguments matched to formal parameters.

Reconstructs the call as if all arguments were named according to the function’s formal parameter list. Useful for programming on the language.

@param definition the function whose formals to match against (default: parent function) @param call the call to match (default: parent’s call) @return language object with matched arguments