interp_negate

Function interp_negate 

fn interp_negate(
    positional: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Negate a predicate function, returning a new function that returns the logical complement of the original.

@param f predicate function @return a new closure that calls f and negates the result