interp_sapply

Function interp_sapply 

fn interp_sapply(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Apply a function over a vector or list, simplifying the result.

@param X vector or list to iterate over @param FUN function to apply to each element @return simplified vector or list of results