interp_search

Function interp_search 

fn interp_search(
    _args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Return the search path as a character vector.

The search path represents the order in which environments are searched for names: .GlobalEnv -> attached packages -> package:base.

@return character vector of environment names on the search path