interp_source

Function interp_source 

fn interp_source(
    positional: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Read and evaluate an R source file.

@param file path to the R source file @return the result of evaluating the last expression in the file