interp_sys_call

Function interp_sys_call 

fn interp_sys_call(
    positional: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Get the call expression of a frame on the call stack.

@param which frame number (0 = current, positive = counting from bottom) @return the call as a language object, or NULL