interp_sys_calls

Function interp_sys_calls 

fn interp_sys_calls(
    _positional: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Get the list of all calls on the call stack.

@return list of call language objects for all active frames