interp_sys_source

Function interp_sys_source 

fn interp_sys_source(
    positional: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Read and evaluate an R source file in a specified environment.

Like source(), but evaluates the expressions in the given environment rather than the global environment. This is useful for loading code into a specific namespace or local environment.

@param file path to the R source file @param envir environment in which to evaluate (default: base environment) @return the result of evaluating the last expression in the file (invisibly)