interp_tapply

Function interp_tapply 

fn interp_tapply(
    positional: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Apply a function to groups of values defined by a factor/index.

@param X vector of values to split into groups @param INDEX factor or vector defining the groups @param FUN function to apply to each group @return named vector or list of per-group results