json_array_to_rvalue

Function json_array_to_rvalue 

fn json_array_to_rvalue(arr: &[Value]) -> Result<RValue, RError>
Convert a JSON array to an R value.

If all elements are scalars of the same type, produce an atomic vector. If all elements are objects with the same keys, produce a data.frame. Otherwise, produce a list.