builtin_log

Function builtin_log 

fn builtin_log(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Logarithm. With one argument, computes the natural log. With a second positional argument or named base argument, computes log in that base via the change-of-base formula: log(x, base) = ln(x) / ln(base).

@param x numeric vector @param base the base of the logarithm (default: e, i.e. natural log) @return numeric vector of logarithms