builtin_rep

Function builtin_rep 

fn builtin_rep(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Replicate elements of a vector.

@param x a vector @param times number of times to repeat the whole vector (default 1) @param each number of times to repeat each element before moving to the next @param length.out desired output length (truncates or extends the result) @return vector with elements repeated