builtin_sweep

Function builtin_sweep 

fn builtin_sweep(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Sweep a summary statistic from each row or column of a matrix.

@param x a numeric matrix @param MARGIN 1 for rows, 2 for columns @param STATS a numeric vector of statistics to sweep out @param FUN the function to use: “-” (default), “+”, “*”, “/” @return a matrix of the same dimensions as x @namespace base