builtin_dot_external2

Function builtin_dot_external2 

fn builtin_dot_external2(
    args: &[RValue],
    _named: &[(String, RValue)],
    ctx: &BuiltinContext<'_>,
) -> Result<RValue, RError>
.External2 — like .External but C function receives (call, op, args, env).

For our purposes, we dispatch the same as .External since we don’t have a real call object or op to pass. The C function gets a pairlist of args.

@param .NAME character string naming the C function @param … arguments passed to the native function @return the value returned by the native function @namespace base