pre_eval_rm

Function pre_eval_rm 

fn pre_eval_rm(
    args: &[Arg],
    env: &Environment,
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Remove objects from an environment.

Supports non-standard evaluation: bare symbol names are interpreted as the names of objects to remove (e.g., rm(x) removes the variable x). Also accepts character strings for compatibility: rm("x").

@param … names of objects to remove (bare symbols or character strings) @param list character vector of names to remove @param envir environment from which to remove (default: calling environment) @return NULL (invisibly)