pre_eval_substitute

Function pre_eval_substitute 

fn pre_eval_substitute(
    args: &[Arg],
    env: &Environment,
    _context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Return an unevaluated expression with variables substituted from the environment.

@param expr any R expression (not evaluated) @return the expression with symbols replaced by their values from the calling environment