pre_eval_try

Function pre_eval_try 

fn pre_eval_try(
    args: &[Arg],
    env: &Environment,
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Evaluate an expression, catching errors and returning them as a string.

@param expr the expression to evaluate @return the result of expr on success, or the error message as a character string