pre_eval_try_catch

Function pre_eval_try_catch 

fn pre_eval_try_catch(
    args: &[Arg],
    env: &Environment,
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Evaluate an expression with error/warning/message handlers.

@param expr the expression to evaluate @param error handler function for error conditions (optional) @param warning handler function for warning conditions (optional) @param message handler function for message conditions (optional) @param finally expression to evaluate after expr, regardless of outcome (optional) @return the result of expr, or the return value of the matching handler