interp_rfrechet

Function interp_rfrechet 

fn interp_rfrechet(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Random Frechet (Type II extreme value) deviates.

miniR extension – not available in base R.

The Frechet distribution models the maximum of many random variables. It is parameterised by shape alpha, scale s, and location m.

@param n number of observations @param alpha shape parameter (positive) @param s scale parameter (positive, default 1) @param m location parameter (default 0) @return numeric vector of length n