interp_rhyper

Function interp_rhyper 

fn interp_rhyper(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Random hypergeometric deviates.

Generates nn random values from a hypergeometric distribution.

@param nn number of observations @param m number of white balls in the urn @param n number of black balls in the urn @param k number of balls drawn from the urn @return integer vector of length nn