interp_rlnorm

Function interp_rlnorm 

fn interp_rlnorm(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Random log-normal deviates.

Generates n random values from a log-normal distribution.

@param n number of observations @param meanlog mean of the distribution on the log scale (default 0) @param sdlog standard deviation on the log scale (default 1) @return numeric vector of length n