builtin_representation

Function builtin_representation 

fn builtin_representation(
    _args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Create a named character vector describing S4 slot types.

This is used as the representation or slots argument to setClass(). Each named argument specifies a slot name and its type as a character string.

@param … named arguments where names are slot names and values are type strings @return a named character vector