builtin_slot_set

Function builtin_slot_set 

fn builtin_slot_set(
    args: &[RValue],
    _named: &[(String, RValue)],
) -> Result<RValue, RError>
Set a slot on an S4 object (replacement function).

Sets a named element on the underlying list, equivalent to @<-.

@param object an S4 object (list with class attribute) @param name character string naming the slot @param value the new value for the slot @return the modified object