interp_exists_method

Function interp_exists_method 

fn interp_exists_method(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Check if a method exists for a given generic and signature.

Looks up the method in the S4 dispatch table.

@param f character string naming the generic function @param signature character string or vector for the method signature @return TRUE if a method exists, FALSE otherwise