interp_is

Function interp_is 

fn interp_is(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Check if an object is an instance of a class (S4-compatible).

Checks the class attribute and then walks the S4 inheritance chain from the class registry to determine if the object inherits from the specified class.

@param object any R object @param class2 character string naming the class to check @return TRUE if the object inherits from class2, FALSE otherwise