interp_set_class_s4

Function interp_set_class_s4 

fn interp_set_class_s4(
    args: &[RValue],
    named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Define an S4 class.

Registers the class in the per-interpreter S4 class registry with its slot definitions, superclasses (inheritance), and prototype defaults.

@param Class character string naming the class @param representation named list/vector of slot types (synonym for slots) @param slots named list/vector of slot types @param contains character vector of superclass names @param prototype named list of default slot values @param validity validity-checking function @param sealed logical, whether the class definition is sealed @return the class name (invisibly)