builtin_dlnorm

Function builtin_dlnorm 

fn builtin_dlnorm(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Log-normal density function.

@param x quantile vector @param meanlog mean of the distribution on the log scale (default 0) @param sdlog standard deviation on the log scale (default 1) @return numeric vector of densities