builtin_phyper

Function builtin_phyper 

fn builtin_phyper(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Hypergeometric cumulative distribution function.

@param q quantile vector @param m number of white balls in the urn @param n number of black balls in the urn @param k number of balls drawn from the urn @return numeric vector of probabilities