builtin_qhyper

Function builtin_qhyper 

fn builtin_qhyper(
    args: &[RValue],
    named: &[(String, RValue)],
) -> Result<RValue, RError>
Hypergeometric quantile function (inverse CDF).

@param p probability vector @param m number of white balls in the urn @param n number of black balls in the urn @param k number of balls drawn from the urn @return numeric vector of quantiles