builtin_deparse

Function builtin_deparse 

fn builtin_deparse(
    args: &[RValue],
    _: &[(String, RValue)],
) -> Result<RValue, RError>
Convert an R expression or value to its string representation.

@param expr any R value or language object @return character scalar containing the deparsed representation