fn builtin_regexec(
args: &[RValue],
named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Match a pattern with capture groups against a character vector.
@param pattern character scalar: regular expression with optional capture groups @param text character vector to search @param fixed logical: if TRUE, pattern is a literal string @param ignore.case logical: if TRUE, matching is case-insensitive @return list of integer vectors with match and capture-group positions