fn builtin_strrep(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Repeat each element of a character vector a specified number of times.
@param x a character vector @param times an integer vector of repetition counts (recycled) @return a character vector with each element repeated