interp_dput

Function interp_dput 

fn interp_dput(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Write a deparsed representation of an R object to stdout.

@param x any R value or language object @return NULL (invisibly); output is printed to stdout