interp_is_namespace

Function interp_is_namespace 

fn interp_is_namespace(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Check if an object is a namespace environment.

Returns TRUE if the object is an environment whose name starts with “namespace:” (indicating it was created by the package loader), or if it matches one of the loaded namespace environments in the interpreter’s registry.

@param ns object to check @return logical @namespace base