interp_sys_which

Function interp_sys_which 

fn interp_sys_which(
    args: &[RValue],
    _named: &[(String, RValue)],
    context: &BuiltinContext<'_>,
) -> Result<RValue, RError>
Look up the full paths of programs on the system PATH.

@param names character vector: program names to search for @return named character vector: full paths (empty string if not found), with names set to the input program names (matching R behavior)