fn array_of_tables_to_rvalue(aot: &ArrayOfTables) -> Result<RValue, RError>Expand description
Convert an array of tables (TOML [[section]]) to an R value.
If all tables have the same keys, produce a data.frame. Otherwise, produce a list.
fn array_of_tables_to_rvalue(aot: &ArrayOfTables) -> Result<RValue, RError>Convert an array of tables (TOML [[section]]) to an R value.
If all tables have the same keys, produce a data.frame. Otherwise, produce a list.