PromiseExprs

Type Alias PromiseExprs 

type PromiseExprs = FnvHashMap<String, Expr>;
Source expressions for function arguments (promise expressions).

When a closure is called, the original unevaluated expressions for each argument are stored here so that substitute() can retrieve them.

Aliased Type

struct PromiseExprs { /* private fields */ }