ParState

Struct ParState 

pub struct ParState {
Show 17 fields pub col: RColor, pub bg: RColor, pub lwd: f64, pub lty: LineType, pub pch: i64, pub cex: f64, pub ps: f64, pub font: FontFace, pub family: String, pub mar: [f64; 4], pub mfrow: [i64; 2], pub mfcol: [i64; 2], pub usr: [f64; 4], pub las: i64, pub xaxs: String, pub yaxs: String, pub new: bool,
}
Full graphical parameter state, mirroring R’s par() settings.

Fields

col: RColor

Foreground (drawing) color

bg: RColor

Background color

lwd: f64

Line width

lty: LineType

Line type

pch: i64

Plotting character (symbol)

cex: f64

Character expansion factor

ps: f64

Point size of text (in big points)

font: FontFace

Font face

family: String

Font family name

mar: [f64; 4]

Margins (bottom, left, top, right) in lines

mfrow: [i64; 2]

Multi-figure layout: rows, cols (set by mfrow)

mfcol: [i64; 2]

Multi-figure layout: rows, cols (set by mfcol)

usr: [f64; 4]

User coordinate limits: xmin, xmax, ymin, ymax

las: i64

Axis label style: 0=parallel, 1=horizontal, 2=perpendicular, 3=vertical

xaxs: String

X-axis interval calculation style (“r” or “i”)

yaxs: String

Y-axis interval calculation style (“r” or “i”)

new: bool

Whether plot.new() has been called on the current device

Implementations

Source

impl ParState

pub fn get(&self, name: &str) -> Option<RValue>

Get a graphical parameter value by name, returning it as an RValue.

pub fn set( &mut self, name: &str, value: &RValue, ) -> Result<Option<RValue>, RError>

Set a graphical parameter by name. Returns the old value on success.

pub fn known_params() -> &'static [&'static str]

Return all parameter names that this state knows about.