emulate_configure_system_lib

Function emulate_configure_system_lib 

fn emulate_configure_system_lib(
    pkg_src_dir: &Path,
    pkg_config_name: &str,
    fallback_cppflags: &str,
)
Generic configure emulation: replace a bundled static lib build with system library found via pkg-config. Writes a Makevars that uses system headers and libs instead of bundled source.