pub fn init_global_envs(base_env: &Environment, global_env: &Environment)Expand description
Initialize the global R_BaseEnv, R_GlobalEnv, R_EmptyEnv SEXPs from interpreter envs. Called once from the package loader before the first .Call.
pub fn init_global_envs(base_env: &Environment, global_env: &Environment)Initialize the global R_BaseEnv, R_GlobalEnv, R_EmptyEnv SEXPs from interpreter envs. Called once from the package loader before the first .Call.