parse_dcf

Function parse_dcf 

fn parse_dcf(input: &str) -> Result<HashMap<String, String>, DescriptionError>
Parse DCF (Debian Control File) format into a field map.

Returns fields in their original casing. Continuation lines are joined with a single space (leading whitespace on continuation lines is stripped, but the continuation itself is space-separated from the previous line).