extract_help_topic

Function extract_help_topic 

fn extract_help_topic(pair: &Pair<'_, Rule>) -> String
Extract the topic name from a help expression for ?foo or ?foo(...). Strips leading ?, then extracts the function name from call expressions (e.g. plot(1:10)plot).