fn interp_hashmap_get(
args: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Look up a key in a HashMap, with an optional default.
@param h integer scalar: hashmap ID
@param key character scalar: the key to look up
@param default value to return if the key is not found (default NULL)
@return the stored value, or default if the key does not exist