fn builtin_invoke_restart(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Invoke a restart by name, transferring control to the corresponding handler.
@param r character string naming the restart to invoke @return does not return; transfers control to the restart handler