fn builtin_date(
_args: &[RValue],
_named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Return the current date and time as a character string.
The format matches R’s date(): “Wed Mar 18 12:00:00 2026” (ctime-style: abbreviated weekday, month, day, HH:MM:SS, 4-digit year).
@return character string representing the current date and time