fn builtin_args(
args: &[RValue],
_named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
args(fn) — return the formals of a function (simplified: same as formals).
In GNU R, args() returns a function with the same formals but NULL body.
We simplify to just returning formals, which covers all practical uses.