fn builtin_col_names_set(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Set the column names of a data frame or matrix.
@param x data frame, matrix, or object with dimnames @param value character vector of new column names, or NULL @return the modified object