fn builtin_matrix(
args: &[RValue],
named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Create a matrix from the given data.
Fills column-by-column by default. Use byrow = TRUE for row-major fill.
@param data vector of values to fill the matrix @param nrow number of rows @param ncol number of columns @param byrow if TRUE, fill by rows instead of columns @param dimnames list of row and column name vectors @return matrix (vector with dim and class attributes)