fn builtin_pmatch(
args: &[RValue],
_: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Partial string matching — find unique partial matches of x in table.
For each element of x, returns the position of its unique partial match in table (i.e. the table element that starts with x). Returns NA if no match or if multiple table entries match (ambiguous). Exact matches are preferred.
@param x values to look up (partial strings) @param table values to match against @return integer vector of match positions (1-indexed), or NA for no/ambiguous match