fn interp_hist(
args: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Compute a histogram and display it as a bar chart.
@param x numeric vector of data values @param breaks number of bins (default 10) or a vector of break points @param col bar color @param main plot title @param xlab x-axis label @return a list with breaks, counts, and mids (invisibly)