fn interp_down_viewport(
args: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Navigate down to a named viewport in the stack.
@param name the name of the viewport to navigate to @return the depth navigated (integer), or error if not found