fn interp_grid_remove(
args: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Remove a grob from the display list by name.
@param name character string naming the grob to remove @return NULL (invisibly)