fn interp_unit(
args: &[RValue],
named: &[(String, RValue)],
_context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Create a unit object representing a measurement with given units.
Supported units include: “npc”, “cm”, “inches”, “mm”, “points”, “lines”, “native”, “null”, “char”, “grobwidth”, “grobheight”, “strwidth”, “strheight”.
@param x numeric value(s) for the unit @param units character string specifying the unit type @param data optional data for special units (e.g., grob for “grobwidth”) @return a unit object (list with class “unit”)