fn make_grob(
type_class: &str,
entries: Vec<(String, RValue)>,
draw: bool,
vp: RValue,
ctx: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Helper to create a grob and optionally draw it.
- Creates the grob R object (list with class
c(type_class, "grob")) - If
draw=TRUE, records it on the display list - If
vpis provided, pushes the viewport, records the grob, pops the viewport - Returns the grob invisibly