fn record_rust_grob(grob: Grob, ctx: &BuiltinContext<'_>)Expand description
Record a Rust grob on the Rust display list.
Creates the Rust Grob, adds it to the GrobStore, and records a
DisplayItem::Draw on the Rust DisplayList.
fn record_rust_grob(grob: Grob, ctx: &BuiltinContext<'_>)Record a Rust grob on the Rust display list.
Creates the Rust Grob, adds it to the GrobStore, and records a
DisplayItem::Draw on the Rust DisplayList.