fn interp_by(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Apply a function to subsets of a data frame or vector split by a grouping factor.
@param data data frame or vector to split @param INDICES factor or vector defining the groups @param FUN function to apply to each subset @return list of per-group results