fn interp_find(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Find the first element of a vector for which a predicate returns TRUE.
@param f predicate function returning a logical scalar @param x vector or list to search @param right if TRUE, search from right to left @return the first matching element, or NULL if none found