fn interp_get0(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Like get() but returns a default value instead of erroring when not found.
@param x character string giving the variable name
@param envir environment to look in (default: calling environment)
@param ifnotfound value to return if x is not found (default: NULL)
@return the value of the variable, or ifnotfound if not present