fn interp_make_active_binding(
positional: &[RValue],
_named: &[(String, RValue)],
_context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Create an active binding.
Active bindings call a function every time they are accessed.
The function fun is stored in the environment and re-evaluated
on every read of sym.
@param sym name for the binding (character string) @param fun zero-argument function to call on access @param env environment in which to create the binding @return NULL (invisibly)