fn interp_map(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Apply a function to corresponding elements of multiple vectors or lists.
@param f function to apply @param … vectors or lists to map over in parallel @return list of results