fn interp_mapply(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Apply a function to corresponding elements of multiple vectors.
@param FUN function to apply @param … vectors to iterate over in parallel @param MoreArgs list of additional arguments passed to FUN in every call @param SIMPLIFY if TRUE, simplify the result to a vector or matrix @return simplified vector or list of results