fn interp_options(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Get or set global options.
With no arguments, returns all current options as a named list. With character arguments, returns the named options. With name=value pairs, sets those options and returns the previous values.
@param … option names to query, or name=value pairs to set @return list of (previous) option values