fn interp_recall(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Recursively call the current function with new arguments.
Recall(...) finds the currently executing user function from the call stack
and calls it again with the supplied arguments. This is useful for anonymous
recursive functions that don’t have a name to call themselves by.
@param … arguments to pass to the recursive call @return the result of calling the current function with the new arguments