fn interp_reduce(
positional: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Reduce a vector or list to a single value by applying a binary function.
@param f binary function taking two arguments @param x vector or list to reduce @param init optional initial value for the accumulator @param accumulate if TRUE, return all intermediate results @return the final accumulated value, or a list of intermediate values if accumulate=TRUE