fn interp_unsplit(
positional: &[RValue],
_named: &[(String, RValue)],
_context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Reverse of split: reassemble a vector from a split list.
@param value list of vectors (as produced by split()) @param f factor or vector defining the groups (same length as the original vector) @return vector with elements placed back at their original positions