fn builtin_scan(
args: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Read data from a file, splitting into tokens.
@param file character scalar: path to the file to read
@param what example value determining the return type (default: character)
@param sep character scalar: token separator (default: whitespace)
@return vector of tokens coerced to the type of what