fn builtin_slice_index(
args: &[RValue],
named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Return an array of indices along a specified margin.
For a matrix, MARGIN = 1 gives row indices (same as row()),
MARGIN = 2 gives column indices (same as col()).
@param x array (must have dim attribute) @param MARGIN integer: which dimension to generate indices for (1-based) @return integer array of same dimensions as x @namespace base