fn builtin_dot_call(
args: &[RValue],
_named: &[(String, RValue)],
ctx: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
.Call — invoke a compiled C function via the native code pipeline.
The first argument is the function name (character string). Remaining arguments are passed as SEXP values to the C function.
@param .NAME character string naming the C function @param … arguments passed to the native function @return the value returned by the native function @namespace base