fn builtin_dot_external(
args: &[RValue],
_named: &[(String, RValue)],
ctx: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
.External — invoke a compiled C function via the .External calling convention.
Like .Call but passes all arguments as a single pairlist SEXP.
The C function signature is SEXP fn(SEXP args).
@param .NAME character string naming the C function @param … arguments passed to the native function @return the value returned by the native function @namespace base