fn pre_eval_with_calling_handlers(
args: &[Arg],
env: &Environment,
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Evaluate an expression with calling handlers for conditions.
Unlike tryCatch, handlers run without unwinding the call stack, allowing the signaling code to resume execution after the handler returns.
@param expr the expression to evaluate @param … named handlers: class = handler_function @return the result of expr