fn interp_rzeta(
args: &[RValue],
named: &[(String, RValue)],
context: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Random Zeta deviates.
miniR extension – not available in base R.
The Zeta distribution is a discrete power-law distribution on positive
integers. It is the limit of the Zipf distribution as n -> infinity.
The parameter s must be strictly greater than 1.
@param n number of observations @param s shape parameter (must be > 1) @return numeric vector of length n (values are positive integers stored as doubles)