fn builtin_slot(
args: &[RValue],
_named: &[(String, RValue)],
) -> Result<RValue, RError>Expand description
Extract a slot from an S4 object.
Extracts a named element from the underlying list, equivalent to the
@ operator.
@param object an S4 object (list with class attribute) @param name character string naming the slot @return the slot value, or an error if the slot doesn’t exist