fn toml_array_to_rvalue(arr: &Array) -> Result<RValue, RError>Expand description
Convert a TOML array to an R value.
If all elements are scalars of the same type, produce an atomic vector. If all elements are tables with the same keys, produce a data.frame. Otherwise, produce a list.