fn interp_par(
args: &[RValue],
named: &[(String, RValue)],
ctx: &BuiltinContext<'_>,
) -> Result<RValue, RError>Expand description
Query or set graphical parameters.
When called with no arguments, returns all graphical parameters as a named list. When called with string arguments, returns those parameters. When called with named arguments, sets those parameters and returns the old values.
@param … parameter names (as strings) or name=value pairs @return named list of (old) parameter values