pub struct ParState {Show 17 fields
pub col: RColor,
pub bg: RColor,
pub lwd: f64,
pub lty: LineType,
pub pch: i64,
pub cex: f64,
pub ps: f64,
pub font: FontFace,
pub family: String,
pub mar: [f64; 4],
pub mfrow: [i64; 2],
pub mfcol: [i64; 2],
pub usr: [f64; 4],
pub las: i64,
pub xaxs: String,
pub yaxs: String,
pub new: bool,
}Expand description
Full graphical parameter state, mirroring R’s par() settings.
Fields
col: RColorForeground (drawing) color
bg: RColorBackground color
lwd: f64Line width
lty: LineTypeLine type
pch: i64Plotting character (symbol)
cex: f64Character expansion factor
ps: f64Point size of text (in big points)
font: FontFaceFont face
family: StringFont family name
mar: [f64; 4]Margins (bottom, left, top, right) in lines
mfrow: [i64; 2]Multi-figure layout: rows, cols (set by mfrow)
mfcol: [i64; 2]Multi-figure layout: rows, cols (set by mfcol)
usr: [f64; 4]User coordinate limits: xmin, xmax, ymin, ymax
las: i64Axis label style: 0=parallel, 1=horizontal, 2=perpendicular, 3=vertical
xaxs: StringX-axis interval calculation style (“r” or “i”)
yaxs: StringY-axis interval calculation style (“r” or “i”)
new: boolWhether plot.new() has been called on the current device
Implementations
Sourceimpl ParState
impl ParState
Sourcepub fn get(&self, name: &str) -> Option<RValue>
pub fn get(&self, name: &str) -> Option<RValue>
Get a graphical parameter value by name, returning it as an RValue.
Sourcepub fn set(
&mut self,
name: &str,
value: &RValue,
) -> Result<Option<RValue>, RError>
pub fn set( &mut self, name: &str, value: &RValue, ) -> Result<Option<RValue>, RError>
Set a graphical parameter by name. Returns the old value on success.
Sourcepub fn known_params() -> &'static [&'static str]
pub fn known_params() -> &'static [&'static str]
Return all parameter names that this state knows about.