pub fn replay(
list: &DisplayList,
store: &GrobStore,
renderer: &mut dyn GridRenderer,
)Expand description
Replay a display list through a renderer, resolving all units to device cm.
This walks the display list items in order:
PushViewportpushes a viewport and optionally clipsPopViewportpops and unclipsDrawresolves the grob’s units against the current viewport transform and calls the appropriate renderer method