fn emulate_configure_fs(pkg_src_dir: &Path)Expand description
Generate Makevars for fs package using system libuv instead of bundled.
The fs package bundles libuv and builds it from source using autotools. We bypass that by using the system libuv (found via pkg-config).