pub unsafe fn sexp_to_rvalue(s: Sexp) -> RValue
Convert a SEXP result from native C code back to an RValue.
s must be a valid SEXP pointer allocated by our runtime or by C code using our allocVector.
s