pub unsafe fn free_sexp(s: Sexp)Expand description
Free a SEXP and its data buffer using the C allocator.
Safety
s must have been allocated by alloc_vector, mk_char, mk_null,
or by the C runtime in Rinternals.h (which also uses calloc/malloc).
Must not be called twice on the same pointer.